==> estateplat-common-1.2.4-20210112.082606-615-sources.jar: cn/gtmap/estateplat/model/exchange/unidofrmity/KttFwZrzBdc.java <==
package cn.gtmap.estateplat.model.exchange.unidofrmity;

import cn.gtmap.estateplat.model.exchange.national.KttFwZrz;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;
import cn.gtmap.estateplat.utils.JaxbStringNoNullAdapter;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

public class KttFwZrzBdc extends KttFwZrz {
    private String dffwjgdm;
    private String dffwjgmc;
    private String dfghytdm;
    private String dfghytmc;

    @XmlAttribute(
            name = "DFFWJGDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDffwjgdm() {
        return dffwjgdm;
    }

    public void setDffwjgdm(String dffwjgdm) {
        this.dffwjgdm = dffwjgdm;
    }
    @XmlAttribute(
            name = "DFFWJGMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDffwjgmc() {
        return dffwjgmc;
    }

    public void setDffwjgmc(String dffwjgmc) {
        this.dffwjgmc = dffwjgmc;
    }

    @XmlAttribute(
            name = "DFGHYTDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfghytdm() {
        return dfghytdm;
    }

    public void setDfghytdm(String dfghytdm) {
        this.dfghytdm = dfghytdm;
    }

    @XmlAttribute(
            name = "DFGHYTMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfghytmc() {
        return dfghytmc;
    }

    public void setDfghytmc(String dfghytmc) {
        this.dfghytmc = dfghytmc;
    }
}

==> estateplat-common-1.2.4-20230417.005339-1157-sources.jar: cn/gtmap/estateplat/model/exchange/unidofrmity/KttFwZrzBdc.java <==
package cn.gtmap.estateplat.model.exchange.unidofrmity;

import cn.gtmap.estateplat.model.exchange.national.newStandard.KttFwZrzNew;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;

import javax.persistence.Table;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
@Table(name = "KTT_FW_ZRZ")
public class KttFwZrzBdc extends KttFwZrzNew {
    private String dffwjgdm;
    private String dffwjgmc;
    private String dfghytdm;
    private String dfghytmc;

    @XmlAttribute(
            name = "DFFWJGDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDffwjgdm() {
        return dffwjgdm;
    }

    public void setDffwjgdm(String dffwjgdm) {
        this.dffwjgdm = dffwjgdm;
    }
    @XmlAttribute(
            name = "DFFWJGMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDffwjgmc() {
        return dffwjgmc;
    }

    public void setDffwjgmc(String dffwjgmc) {
        this.dffwjgmc = dffwjgmc;
    }

    @XmlAttribute(
            name = "DFGHYTDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfghytdm() {
        return dfghytdm;
    }

    public void setDfghytdm(String dfghytdm) {
        this.dfghytdm = dfghytdm;
    }

    @XmlAttribute(
            name = "DFGHYTMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfghytmc() {
        return dfghytmc;
    }

    public void setDfghytmc(String dfghytmc) {
        this.dfghytmc = dfghytmc;
    }
}
